Learn R Programming

OPL (version 1.0.2)

opl_dt_max_choice: User selection on multiple choice

Description

Function that allows the user to select a row of maximum welfare among the rows with maximum welfare constrained. The function prints out the result and requires user input to select the row.

Usage

opl_dt_max_choice(nc, col_max, verbose = TRUE)

Value

Return the user's selection as an input.

Arguments

nc

Numeber of max welfare.

col_max

Row index for max constrained welfare.

verbose

Set TRUE to print the output on the console.