Function that allows the user to select a row of maximum welfare among the rows with maximum welfare constrained. The function prints out the result and requires user input to select the row.
opl_dt_max_choice(nc, col_max, verbose = TRUE)Return the user's selection as an input.
Numeber of max welfare.
Row index for max constrained welfare.
Set TRUE to print the output on the console.